@@ -7,13 +7,13 @@ This program is intended as a demonstration and is fully virtual.
 
 Required hardware:
   - A CUDA compatible GPU (and pycuda installed)
+Requires the cv2 module to be installed.
 """
 
 import crappy
-import cv2
 
 if __name__ == "__main__":
-  img = cv2.imread('data/speckle.png', 0)
+  img = crappy.resources.speckle
 
   speed = 5 / 60  # mm/sec
 
@@ -26,15 +26,17 @@ if __name__ == "__main__":
 
   # Our fake machine
   machine = crappy.blocks.Fake_machine(maxstrain=17, k=5000, l0=20,
-      plastic_law=lambda exx: 0, sigma={'F(N)': 0.5})
+                                       plastic_law=lambda exx: 0,
+                                       sigma={'F(N)': 0.5})
 
   crappy.link(generator, machine)
   crappy.link(machine, generator)
 
   # The block performing the DIC
   dis = crappy.blocks.GPUCorrel('', input_label='frame', verbose=True,
-      labels=['x', 'y', 'measured_Exx(%)', 'measured_Eyy(%)'],
-      fields=['x', 'y', 'exx', 'eyy'])
+                                labels=['x', 'y', 'measured_Exx(%)',
+                                        'measured_Eyy(%)'],
+                                fields=['x', 'y', 'exx', 'eyy'])
   # This modifier will generate an image with the values of strain
   # coming from the Fake_machine block
   crappy.link(machine, dis, modifier=crappy.modifier.Apply_strain_img(img))
