@@ -1,19 +1,20 @@
 # coding: utf-8
 
 from time import time
+from typing import Callable, Union
 
 
 class Path(object):
   """Parent class for all paths."""
 
-  def __init__(self, time, cmd):
+  def __init__(self, time: float, cmd: float) -> None:
     self.t0 = time
     self.cmd = cmd
 
-  def get_cmd(self, data):
+  def get_cmd(self, data: dict) -> float:
     return self.cmd
 
-  def parse_condition(self, condition):
+  def parse_condition(self, condition: Union[str, bool, Callable]) -> Callable:
     """This method turns a string into a function that returns a bool.
 
     It is meant to check if a skip condition is reached.
@@ -36,7 +37,8 @@ class Path(object):
     if not isinstance(condition, str):
       if condition is None or not condition:
         return lambda _: False  # For never ending conditions
-      return condition
+      elif isinstance(condition, Callable):
+        return condition
     if '<' in condition:
       var, val = condition.split('<')
       return lambda data: any([i < float(val) for i in data[var]])
@@ -47,4 +49,5 @@ class Path(object):
       val = float(condition.split('=')[1])
       return lambda data: time() - self.t0 > val
     else:
-      return lambda data: True
+      raise ValueError("Wrong syntax for the condition, please refer to the "
+                       "documentation")
