@@ -1,6 +1,7 @@
 # coding: utf-8
 
 from time import time, sleep
+from re import fullmatch, findall
 from typing import List, Union
 from .inout import InOut
 from ..tool import ft232h_server as ft232h, Usb_server
@@ -77,7 +78,7 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
 
   The Waveshare_ad_da InOut block is meant for communicating with Waveshare's
   AD/DA Raspberry Pi hat from an FT232H, using the SPI protocol and the GPIOs.
-  It allows to read values from the 8-channels ADC and/or to set the 2-channels
+  It allows reading values from the 8-channels ADC and/or to set the 2-channels
   DAC.
 
   Warning:
@@ -98,14 +99,14 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
                cs_pin_ads: str = 'D4',
                drdy_pin_ads: str = 'D6',
                cs_pin_dac: str = 'D5') -> None:
-    """Checks the arguments validity.
+    """Checks the validity of the arguments.
 
     Args:
       dac_channels (:obj:`list`, optional): A :obj:`list` of :obj:`str`
         representing the channels to be set. The syntax for each string is
         'DACi' with i being either `0` or `1`.
       adc_channels (:obj:`list`, optional): A :obj:`list` of :obj:`str`
-        representing the channels to be read. The syntax for all strings is
+        representing the channels to read. The syntax for all strings is
         either:
         ::
 
@@ -117,7 +118,7 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
           'ADi - ADj' (i, j in range(8))
 
       gain_hardware (:obj:`int`, optional): The gain to be used by the
-        programmable gain amplifier. Setting a high gain allows to read small
+        programmable gain amplifier. Setting a high gain allows reading small
         voltages with a better precision, but it might saturate the sensor for
         higher voltages. The available gain values are:
         ::
@@ -135,14 +136,14 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
 
           output = gain * tension + offset.
 
-        The same gain applies to all of the outputs.
+        The same gain applies to all the outputs.
       offset (:obj:`float`, optional): Allows to tune the output values of the
         ADC according to the formula:
         ::
 
           output = gain * tension + offset.
 
-        The same offset applies to all of the outputs.
+        The same offset applies to all the outputs.
       sample_rate (optional): The ADC data output rate in SPS. The available
         values are:
         ::
@@ -150,12 +151,12 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
           2.5, 5, 10, 15, 25, 30, 50, 60, 100, 500,
           1000, 2000, 3750, 7500, 15000, 30000
 
-      ft232h_ser_num (:obj:`str`, optional): If backend is `'ft232h'`, the
-        serial number of the ft232h to use for communication.
+      ft232h_ser_num (:obj:`str`, optional): The serial number of the ft232h to
+        use for communication.
       rst_pin_ads (:obj:`str`, optional): The pin for resetting the ADS1256.
       cs_pin_ads (:obj:`str`, optional): The chip select pin for the ADS1256.
-      drdy_pin_ads (:obj:`str`, optional): The pin for knowing when a conversion
-        result in ready.
+      drdy_pin_ads (:obj:`str`, optional): The pin for knowing when a
+        conversion result in ready.
       cs_pin_dac (:obj:`str`, optional): The chip select pin for the DAC8552.
 
     Warning:
@@ -176,13 +177,9 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
         then considered as differential inputs.
 
         The ADC channels voltages should not be lower than `AGND-0.1V`, and not
-        be greater than `AGND+5.1V`. This is independent from `VREF` value.
+        be greater than `AGND+5.1V`. This is independent of `VREF` value.
 
     Note:
-      - ``dac_channels``:
-        As there are 2 DAC channels on the AD/DA, only `1` or `2` strings can
-        be given for the dac_channels argument.
-
       - ``adc_channels``:
         If multiple channels to read are given, they are read in a sequential
         way. This means that there's a small delay between each acquisition,
@@ -191,7 +188,7 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
         read as few channels as possible !
 
       - ``vref``:
-        `VREF` can be set independently from the chosen `VCC` value. The `VCC`
+        `VREF` can be set independently of the chosen `VCC` value. The `VCC`
         value has no influence on the ADC behaviour as it is always powered
         up with `5V`. Same goes for the DAC.
     """
@@ -225,43 +222,39 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
     if dac_channels is None and adc_channels is None:
       print("Warning ! The AD/DA doesn't read nor write anything.")
 
+    self._channels_write = []
     if dac_channels is not None:
-      if len(dac_channels) > 2:
-        raise ValueError("dac_channels length should not exceed 2")
       for chan in dac_channels:
-        if chan not in ["DAC0", "DAC1"]:
+        # Checking if the format matches
+        if fullmatch(r'DAC[0-1]', chan) is None:
           raise ValueError("Valid format for dac_channels values is 'DACi' "
                            "with i either 0 or 1")
-      self._dac_channels = dac_channels
-    else:
-      self._dac_channels = []
+        else:
+          self._channels_write.append(int(findall(r'\d', chan)[0]))
 
+    self._channels_read = []
     if adc_channels is not None:
-      not_valid_message = "Valid formats for adc_channels values are " \
-                          "either 'ADi' (i in range(8)) or 'ADi - ADj'"
       for chan in adc_channels:
-        if len(chan) not in [3, 9]:
-          raise ValueError(not_valid_message)
-        if not chan.startswith("AD"):
-          raise ValueError(not_valid_message)
-        elif len(chan) == 9:
-          if not chan.startswith("-", 4):
-            raise ValueError(not_valid_message)
-          if not chan.startswith("AD", 6):
-            raise ValueError(not_valid_message)
-      if not (all(len(chan) == 3 for chan in adc_channels) or
-              all(len(chan) == 9 for chan in adc_channels)):
-        raise ValueError("It is not possible to have both single and "
-                         "differential inputs, see documentation for more "
-                         "info")
-      self._adc_channels = adc_channels
-    else:
-      self._adc_channels = []
+        # Checking if the format matches
+        if fullmatch(r'AD[0-7]', chan) is None and \
+              fullmatch(r'AD[0-7]\s?-\s?AD[0-7]', chan) is None:
+          raise ValueError("Valid formats for adc_channels values are "
+                           "either 'ADi' (i in range(8)) or 'ADi - ADj'")
+        else:
+          # Extracting the channel numbers
+          chan = [int(i) for i in findall(r'\d', chan)]
+          # If only one channel provided, it has to be compared to GND
+          if len(chan) == 1:
+            chan.append(8)
+          # Making sure the two channels are not identical
+          if chan[0] == chan[1]:
+            raise ValueError("The two channels are the same !")
+          self._channels_read.append(chan)
 
     self._gain = gain
     self._offset = offset
 
-    self._SPI = ft232h(mode='SPI',
+    self._bus = ft232h(mode='SPI',
                        queue=queue,
                        namespace=namespace,
                        command_event=command_event,
@@ -275,37 +268,23 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
     self._drdy_pin_ads = drdy_pin_ads
     self._cs_pin_dac = cs_pin_dac
 
-    self._channels_read, self._channels_write = [], []
-
   def open(self) -> None:
     """Sets the SPI communication, the GPIOs and the device."""
 
     # Setting the SPI
-    self._SPI.max_speed_hz = 40000
-    self._SPI.mode = 1
-    self._SPI.no_cs = True
+    self._bus.max_speed_hz = 40000
+    self._bus.mode = 1
+    self._bus.no_cs = True
     self._reset()
 
     # Setting the ADS according to the user parameters
-    buf = [0x00, 0x00]
-    buf[0] |= Ads1256_gain[self._gain_hardware]
-    buf[1] |= Ads1256_drate[self._sample_rate]
-    self._SPI.set_gpio(self._cs_pin_ads, False)
-    self._SPI.writebytes([Ads1256_cmd['CMD_WREG'] |
-                         Ads1256_reg['REG_ADCON'], 0x01] + buf)
-    self._SPI.set_gpio(self._cs_pin_ads, True)
+    buf = [Ads1256_gain[self._gain_hardware], Ads1256_drate[self._sample_rate]]
+    self._bus.set_gpio(self._cs_pin_ads, False)
+    self._bus.writebytes([Ads1256_cmd['CMD_WREG'] |
+                          Ads1256_reg['REG_ADCON'], 0x01] + buf)
+    self._bus.set_gpio(self._cs_pin_ads, True)
     sleep(0.001)
 
-    # Setting the lists of channels to read and write
-    for chan in self._adc_channels:
-      if len(chan) == 3:
-        self._channels_read.append([int(chan[2]), 8])
-      else:
-        self._channels_read.append([int(chan[2]), int(chan[8])])
-
-    for chan in self._dac_channels:
-      self._channels_write.append(int(chan[3]))
-
   def get_data(self) -> list:
     """Reads data from all the user-specified ADC channels, in a sequential
     way.
@@ -321,34 +300,33 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
 
     # The values are read one channel after the other, not simultaneously
     for chan in self._channels_read:
-      self._SPI.set_gpio(self._cs_pin_ads, False)
+      self._bus.set_gpio(self._cs_pin_ads, False)
 
       # Switching channel only if necessary, except for the first loop
       if len(self._channels_read) > 1 or not self._channel_set:
-        self._SPI.writebytes([Ads1256_cmd['CMD_WREG'] |
-                             Ads1256_reg['REG_MUX'], 0x00,
-                             (chan[0] << 4) | chan[1]], stop=False)
+        self._bus.writebytes([Ads1256_cmd['CMD_WREG'] |
+                              Ads1256_reg['REG_MUX'], 0x00,
+                              (chan[0] << 4) | chan[1]], stop=False)
 
         # The ADS has to be synchronized again when switching channel
-        self._SPI.writebytes([Ads1256_cmd['CMD_SYNC']], start=False, stop=False)
-        self._SPI.writebytes([Ads1256_cmd['CMD_WAKEUP']], start=False)
+        self._bus.writebytes([Ads1256_cmd['CMD_SYNC']],
+                             start=False,
+                             stop=False)
+        self._bus.writebytes([Ads1256_cmd['CMD_WAKEUP']], start=False)
 
         self._channel_set = True
 
       # Reading the output value
       self._wait_drdy()
-      self._SPI.writebytes([Ads1256_cmd['CMD_RDATA']], stop=False)
-      buf = self._SPI.readbytes(3, start=False)
-      self._SPI.set_gpio(self._cs_pin_ads, True)
+      self._bus.writebytes([Ads1256_cmd['CMD_RDATA']], stop=False)
+      buf = self._bus.readbytes(3, start=False)
+      self._bus.set_gpio(self._cs_pin_ads, True)
 
       # Converting the raw output into Volts
       out_raw = (buf[0] << 16) | (buf[1] << 8) | buf[2]
-      if out_raw >> 23:
-        value = self._v_ref / self._gain_hardware * (-(2 ** 23 - 1) + (
-                out_raw & 0x7FFFFF)) / (2 ** 23 - 1)
-      else:
-        value = self._v_ref / self._gain_hardware * out_raw / (
-                2 ** 23 - 1)
+      if out_raw & 0x800000:
+        out_raw -= 2 ** 24
+      value = self._v_ref / self._gain_hardware * out_raw / 2 ** 23
       out.append(self._offset + self._gain * value)
 
     return out
@@ -366,32 +344,30 @@ class Waveshare_ad_da_ft232h(Usb_server, InOut):
         raise ValueError("Desired output voltage should be between 0 and "
                          "v_ref")
       digit = int((2 ** 16 - 1) * val / self._v_ref)
-      self._SPI.set_gpio(self._cs_pin_dac, False)
-      self._SPI.writebytes([Dac8532_chan[channel], digit >> 8,
-                           digit & 0xFF])
-      self._SPI.set_gpio(self._cs_pin_dac, True)
+      self._bus.set_gpio(self._cs_pin_dac, False)
+      self._bus.writebytes([Dac8532_chan[channel], digit >> 8,
+                            digit & 0xFF])
+      self._bus.set_gpio(self._cs_pin_dac, True)
 
   def close(self) -> None:
     """Releases the GPIOs."""
 
-    self._SPI.close()
+    self._bus.close()
 
   def _reset(self) -> None:
     """Resets the ADC."""
 
-    self._SPI.set_gpio(self._cs_pin_ads, True)
+    self._bus.set_gpio(self._cs_pin_ads, True)
     sleep(0.2)
-    self._SPI.set_gpio(self._cs_pin_ads, False)
+    self._bus.set_gpio(self._cs_pin_ads, False)
     sleep(0.2)
-    self._SPI.set_gpio(self._cs_pin_ads, True)
+    self._bus.set_gpio(self._cs_pin_ads, True)
 
   def _wait_drdy(self) -> None:
     """Waits until the `DRDY` pin is driven low, meaning that an ADC conversion
     is ready."""
 
-    t_wait = 0
-    while self._SPI.get_gpio(self._drdy_pin_ads):
-      sleep(0.0001)
-      t_wait += 0.0001
-      if t_wait > 1:
+    t0 = time()
+    while self._bus.get_gpio(self._drdy_pin_ads):
+      if time() - t0 > 1:
         raise TimeoutError("Couldn't get conversion result from the ADC")
