@@ -7,5 +7,5 @@ from .gpucorrel import GPUCorrel
 from .discorrel import DISCorrel
 from .discorrelConfig import DISConfig
 from .disve import DISVE
-from .ft232h import ft232h, ft232h_server
+from .ft232h import ft232h, ft232h_server, i2c_msg_ft232h
 from .usb_server import Usb_server
