@@ -156,7 +156,8 @@ class CorrelStage:
                                        reduce_expr="a+b", map_expr="x[i]*y[i]",
                                        arguments="float *x, float *y")
     self._leastSquare = ReductionKernel(np.float32, neutral="0",
-                                        reduce_expr="a+b", map_expr="x[i]*x[i]",
+                                        reduce_expr="a+b",
+                                        map_expr="x[i]*x[i]",
                                         arguments="float *x")
     # We could have used use mulRedKrnl(x,x), but this is probably faster ?
 
